/*
 * Copyright (c) 2016, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 * <p/>
 * WSO2 Inc. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 * <p/>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p/>
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.wso2.carbon.das.messageflow.data.publisher.observer.jmx.data;

import org.apache.synapse.aspects.flow.statistics.publishing.PublishingEvent;

/**
 * Summery data object to summery data for JMX publisher.
 */
public class SummeryStatisticObject {

    private final String name;

    private long maxTime = 0;

    private long minTime = 0;

    private long avgTime = 0;

    private long count = 0;

    private long faultCount;

    public SummeryStatisticObject(PublishingEvent publishingEvent) {
        name = publishingEvent.getComponentName();
        minTime = maxTime = avgTime = publishingEvent.getDuration();
        count++;
        if (publishingEvent.getFaultCount() > 0) {
            faultCount++;
        }
    }

    public void updateStatistics(PublishingEvent publishingEvent) {
        long duration = publishingEvent.getDuration();
        avgTime = (avgTime * count + duration) / (count + 1);
        if (minTime > duration) {
            minTime = duration;
        } else if (maxTime < duration) {
            maxTime = duration;
        }
        count++;
        if (publishingEvent.getFaultCount() > 0) {
            faultCount++;
        }
    }

    public StatisticsCompositeObject getJmxObject() {
        return new StatisticsCompositeObject(name, maxTime, minTime, avgTime, count, faultCount);
    }
}
